..
   Copyright (C) 2011,2012 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


.. _sec-user-guide:

User guide
**********

.. toctree::

    install
    quickstart
    modelconstruct
    inference
    plot
    advanced
